@@ -1,7 +1,8 @@
-from django.shortcuts import render
 import json
-from abc import ABC,abstractmethod
 import random
+from abc import ABC, abstractmethod
+
+from django.shortcuts import render
 
 
 class BaseChartView(ABC):
@@ -10,7 +11,9 @@ class BaseChartView(ABC):
     title = None
     legend = False
     beginAtZero = False
-    
+    aspectRatio = True
+    width = 100
+    height = 100
 
     @abstractmethod
     def generate_values(self):
@@ -18,23 +21,29 @@ class BaseChartView(ABC):
 
     def generate_options(self):
         options = {
-            "legend": { "display": self.legend },
+            "legend": {"display": self.legend},
             "title": {
                 "display": True if self.title is not None else False,
-                "text": self.title
+                "text": self.title,
             },
         }
         return options
-    
+
     @abstractmethod
     def generate_labels(self):
         pass
 
-    def get_context_data(self,**kwargs):
-        context = super().get_context_data(**kwargs)        
-        context["chart"] = { "data": self._generate_data(), "options": self.generate_options()}
+    def get_context_data(self, **kwargs):
+        context = super().get_context_data(**kwargs)
+        context["chart"] = {
+            "data": self._generate_data(),
+            "options": self.generate_options(),
+        }
         context["type"] = self.type_chart
-            
+        if self.aspectRatio is not True:
+            context["width"] = self.width
+            context["height"] = self.height
+
         return context
 
 
@@ -45,31 +54,25 @@ class BarChartView(BaseChartView):
     def _generate_data(self):
         data = {
             "labels": self.generate_labels(),
-            "datasets": self._generate_dataset(self.generate_values())
+            "datasets": self._generate_dataset(self.generate_values()),
         }
         return json.dumps(data)
 
     def generate_options(self):
-        options = super().generate_options()        
+        options = super().generate_options()
         options["scales"] = {
-            "yAxes": [{
-                "display": True,
-                "ticks": {
-                    "beginAtZero": True
-                }
-            }]
+            "yAxes": [{"display": True, "ticks": {"beginAtZero": True}}]
         }
-           
-        '''options["tooltips"] = {
+
+        """options["tooltips"] = {
             "callbacks": { 
                 "label": json.dumps("function(tooltipItem,data){ var dataset = data.datasets[tooltipItem.datasetIndex]; return dataset; }")
             }
-        }'''
-            
+        }"""
+
         return json.dumps(options)
-        
-    
-    def _generate_dataset(self,values):
+
+    def _generate_dataset(self, values):
         collection = []
         dataset = {
             "label": self.label,
@@ -79,7 +82,6 @@ class BarChartView(BaseChartView):
         collection.append(dataset)
         return collection
 
-
     def _get_color(self):
         return "#{:02x}{:02x}{:02x}".format(
             *map(lambda x: random.randint(0, 255), range(3))
@@ -93,13 +95,14 @@ class RadarChartView(BaseChartView):
     def generate_labels(self):
         return []
 
-    '''
+    """
         Create RadarNodes object and add to datasets list
-    '''
+    """
+
     def generate_values(self):
         return []
 
-    def create_node(self,label,data):
+    def create_node(self, label, data):
         color = self._get_color()
         return {
             "label": label,
@@ -108,33 +111,32 @@ class RadarChartView(BaseChartView):
             "borderColor": color,
             "pointBorderColor": "#fff",
             "pointBackgroundColor": color,
-            "data": list(data)
+            "data": list(data),
         }
-    
+
     def _get_color(self):
         return "rgba({},{},{},0.4)".format(
             *map(lambda x: random.randint(0, 255), range(5))
         )
 
-
-    def _generate_data(self):        
-        return json.dumps({
-            "labels": self.generate_labels(),
-            "datasets": self.generate_values() 
-        })
+    def _generate_data(self):
+        return json.dumps(
+            {"labels": self.generate_labels(), "datasets": self.generate_values()}
+        )
 
     def generate_options(self):
         options = super().generate_options()
         return json.dumps(options)
 
-    '''
+    """
         Generate random rgba colors
-    '''
+    """
+
     def _get_color(self):
         return "rgba({},{},{},0.4)".format(
             *map(lambda x: random.randint(0, 255), range(5))
         )
-    
+
 
 class LineChartView(BaseChartView):
 
@@ -144,26 +146,26 @@ class LineChartView(BaseChartView):
         the params accept `label` string, and `data` list of values (numeric)
         fill is False to default
     """
-    def create_node(self,label,data,fill=False):
+
+    def create_node(self, label, data, fill=False):
         color = self._get_color()
         return {
             "data": list(data),
             "label": label,
             "borderColor": color,
             "backgroundColor": color,
-            "fill": fill
+            "fill": fill,
         }
 
     def generate_options(self):
         options = super().generate_options()
         options["scales"] = {
-            "yAxes": [{
-                "display": True,
-                "ticks": {
-                    "beginAtZero": self.beginAtZero,
-                    "stepSize": 1
+            "yAxes": [
+                {
+                    "display": True,
+                    "ticks": {"beginAtZero": self.beginAtZero, "stepSize": 1},
                 }
-            }],
+            ]
         }
         return json.dumps(options)
 
@@ -172,30 +174,29 @@ class LineChartView(BaseChartView):
             *map(lambda x: random.randint(0, 255), range(5))
         )
 
-    def _generate_data(self):        
-        return json.dumps({
-            "labels": self.generate_labels(),
-            "datasets": self.generate_values() 
-        })
+    def _generate_data(self):
+        return json.dumps(
+            {"labels": self.generate_labels(), "datasets": self.generate_values()}
+        )
 
 
 class GroupChartView(BaseChartView):
-    
+
     type_bar = "bar"
 
-    def create_node(self,data,label):
+    def create_node(self, data, label):
         return {
             "label": label,
-            "backgroundColor": "#{:02x}{:02x}{:02x}".format(*map(lambda x: random.randint(0, 255), range(3))),
-            "data": list(data)
+            "backgroundColor": "#{:02x}{:02x}{:02x}".format(
+                *map(lambda x: random.randint(0, 255), range(3))
+            ),
+            "data": list(data),
         }
-        
-    def _generate_data(self):        
-        return json.dumps({
-            "labels": self.generate_labels(),
-            "datasets": self.generate_values() 
-        })
 
+    def _generate_data(self):
+        return json.dumps(
+            {"labels": self.generate_labels(), "datasets": self.generate_values()}
+        )
 
 
 class HorizontalBarChartView(BarChartView):
@@ -211,15 +212,15 @@ class PieChartView(BarChartView):
 
     def generate_options(self):
         options = {
-            "legend": { "display": self.legend, "position": "right" },
+            "legend": {"display": self.legend, "position": "right"},
             "title": {
                 "display": True if self.title is not None else False,
-                "text": self.title
+                "text": self.title,
             },
-        }      
-            
+        }
+
         return json.dumps(options)
-    
+
     def get_legend_text(self):
         return ""
 
@@ -231,6 +232,3 @@ class PieChartView(BarChartView):
 
 class DoughnutChartView(PieChartView):
     type_chart = "doughnut"
-
-    
-
